Info

Struct Info 

pub struct Info {
    pub version_string: &'static str,
    pub core_version: i32,
    pub api_version: i32,
    pub num_threads: usize,
    pub max_framebuffer_size: u64,
    pub used_framebuffer_size: u64,
}
Contains information about a VapourSynth core.

Fields

version_string: &'static str

String containing the name of the library, copyright notice, core and API versions.

core_version: i32

Version of the core.

api_version: i32

Version of the API.

num_threads: usize

Number of worker threads.

max_framebuffer_size: u64

The framebuffer cache will be allowed to grow up to this size (bytes) before memory is aggressively reclaimed.

used_framebuffer_size: u64

Current size of the framebuffer cache, in bytes.