pub struct CoreRef<'core> { /* private fields */ }Expand description
A reference to a VapourSynth core.
Implementations
Sourceimpl<'core> CoreRef<'core>
impl<'core> CoreRef<'core>
Sourcepub fn get_format(&self, id: FormatID) -> Option<Format<'core>>
pub fn get_format(&self, id: FormatID) -> Option<Format<'core>>
Retrieves a registered or preset Format by its id. The id can be of a previously
registered format, or one of the PresetFormat.
Sourcepub fn register_format(
&self,
color_family: ColorFamily,
sample_type: SampleType,
bits_per_sample: u8,
sub_sampling_w: u8,
sub_sampling_h: u8,
) -> Option<Format<'core>>
pub fn register_format( &self, color_family: ColorFamily, sample_type: SampleType, bits_per_sample: u8, sub_sampling_w: u8, sub_sampling_h: u8, ) -> Option<Format<'core>>
Registers a custom video format.
Returns None if an invalid format is described.
Registering compat formats is not allowed. Only certain privileged built-in filters are allowed to handle compat formats.
RGB formats are not allowed to be subsampled.
Sourcepub fn get_plugin_by_id(
&self,
id: &str,
) -> Result<Option<Plugin<'core>>, NulError>
pub fn get_plugin_by_id( &self, id: &str, ) -> Result<Option<Plugin<'core>>, NulError>
Returns a plugin with the given identifier.
Sourcepub fn get_plugin_by_namespace(
&self,
namespace: &str,
) -> Result<Option<Plugin<'core>>, NulError>
pub fn get_plugin_by_namespace( &self, namespace: &str, ) -> Result<Option<Plugin<'core>>, NulError>
Returns a plugin with the given namespace.
get_plugin_by_id() should be used instead.
Sourcepub fn set_max_cache_size(&self, bytes: i64) -> i64
pub fn set_max_cache_size(&self, bytes: i64) -> i64
Sets the maximum size of the framebuffer cache. Returns the new maximum size.
Sourcepub fn set_thread_count(&self, threads: i32) -> i32
pub fn set_thread_count(&self, threads: i32) -> i32
Sets the number of worker threads for the given core.
If the requested number of threads is zero or lower, the number of hardware threads will be detected and used.
Returns the new thread count.