pub struct Info {
pub version_string: &'static str,
pub core_version: i32,
pub api_version: i32,
pub num_threads: usize,
pub max_framebuffer_size: u64,
pub used_framebuffer_size: u64,
}Expand description
Contains information about a VapourSynth core.
Fields
version_string: &'static strString containing the name of the library, copyright notice, core and API versions.
core_version: i32Version of the core.
api_version: i32Version of the API.
num_threads: usizeNumber of worker threads.
max_framebuffer_size: u64The framebuffer cache will be allowed to grow up to this size (bytes) before memory is aggressively reclaimed.
used_framebuffer_size: u64Current size of the framebuffer cache, in bytes.